@@ -5,11 +5,9 @@ from allauth.socialaccount.providers.oauth2.views import (
     OAuth2LoginView,
 )
 
-from .provider import QuestradeProvider
-
 
 class QuestradeOAuth2Adapter(OAuth2Adapter):
-    provider_id = QuestradeProvider.id
+    provider_id = "questrade"
     access_token_url = "https://login.questrade.com/oauth2/token"
     authorize_url = "https://login.questrade.com/oauth2/authorize"
     supports_state = False
